==> haskell-rank2classes-1.5.5-1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-rank2classes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 rank2classes
version:              1.5.5
visibility:           public
id:                   rank2classes-1.5.5-Lw6yiUNQl9f1ETTWARhO7N
key:                  rank2classes-1.5.5-Lw6yiUNQl9f1ETTWARhO7N
license:              BSD-3-Clause
copyright:            (c) 2017 Mario Blažević
maintainer:           Mario Blažević <blamario@protonmail.com>
author:               Mario Blažević
homepage:             https://github.com/blamario/grampa/tree/master/rank2classes
synopsis:
    standard type constructor class hierarchy, only with methods of rank 2 types

description:
    A mirror image of the standard type constructor class hierarchy rooted in '\''Functor'\'', except with methods of rank 2
    types and class instances of kind @(k->*)->*@. The classes enable generic handling of heterogenously typed data
    structures and other neat tricks.

category:             Control, Data, Generics
abi:                  80896e29c3360ce6490b8188d2979885
exposed:              True
exposed-modules:      Rank2 Rank2.TH
import-dirs:          /usr/lib/ghc-9.6.6/site-local/rank2classes-1.5.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/rank2classes-1.5.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/rank2classes-1.5.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-rank2classes
hs-libraries:         HSrank2classes-1.5.5-Lw6yiUNQl9f1ETTWARhO7N
depends:
    base-4.18.2.1 data-functor-logistic-0.0-3UPPVwyrfekK2pobmjP1cg
    distributive-0.6.2.1-L1zs4X1vyqcJbGQmd1YXaS
    template-haskell-2.20.0.0 transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-rank2classes/html/rank2classes.haddock

haddock-html:         /usr/share/doc/haskell-rank2classes/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-rank2classes-z-doctests
version:              1.5.5
package-name:         rank2classes
lib-name:             doctests
id:                   rank2classes-1.5.5-620eaWDgsQHAGfOjtDlfu0-doctests
key:                  rank2classes-1.5.5-620eaWDgsQHAGfOjtDlfu0-doctests
license:              BSD-3-Clause
copyright:            (c) 2017 Mario Blažević
maintainer:           Mario Blažević <blamario@protonmail.com>
author:               Mario Blažević
homepage:             https://github.com/blamario/grampa/tree/master/rank2classes
synopsis:
    standard type constructor class hierarchy, only with methods of rank 2 types

description:
    A mirror image of the standard type constructor class hierarchy rooted in '\''Functor'\'', except with methods of rank 2
    types and class instances of kind @(k->*)->*@. The classes enable generic handling of heterogenously typed data
    structures and other neat tricks.

category:             Control, Data, Generics
abi:                  6f78e70309fb6303857b6a05d0c7aa3c
hidden-modules:       MyModule
import-dirs:          /usr/lib/ghc-9.6.6/site-local/rank2classes-1.5.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/rank2classes-1.5.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/rank2classes-1.5.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-rank2classes
hs-libraries:         HSrank2classes-1.5.5-620eaWDgsQHAGfOjtDlfu0-doctests
depends:
    base-4.18.2.1 rank2classes-1.5.5-Lw6yiUNQl9f1ETTWARhO7N

haddock-interfaces:
    /usr/share/doc/haskell-rank2classes/html/rank2classes.haddock

haddock-html:         /usr/share/doc/haskell-rank2classes/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-rank2classes-1.5.5.1-1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-rank2classes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 rank2classes
version:              1.5.5.1
visibility:           public
id:                   rank2classes-1.5.5.1-Ajd4u4M9iyH91LaysItqkH
key:                  rank2classes-1.5.5.1-Ajd4u4M9iyH91LaysItqkH
license:              BSD-3-Clause
copyright:            (c) 2017 Mario Blažević
maintainer:           Mario Blažević <blamario@protonmail.com>
author:               Mario Blažević
homepage:             https://github.com/blamario/grampa/tree/master/rank2classes
synopsis:
    standard type constructor class hierarchy, only with methods of rank 2 types

description:
    A mirror image of the standard type constructor class hierarchy rooted in '\''Functor'\'', except with methods of rank 2
    types and class instances of kind @(k->*)->*@. The classes enable generic handling of heterogenously typed data
    structures and other neat tricks.

category:             Control, Data, Generics
abi:                  7713444a957a691d65cde056cd1a0b68
exposed:              True
exposed-modules:      Rank2 Rank2.TH
import-dirs:          /usr/lib/ghc-9.6.6/site-local/rank2classes-1.5.5.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/rank2classes-1.5.5.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/rank2classes-1.5.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-rank2classes
hs-libraries:         HSrank2classes-1.5.5.1-Ajd4u4M9iyH91LaysItqkH
depends:
    base-4.18.2.1 data-functor-logistic-0.0-D2BMCfjpSXQId5pG2sSSYx
    distributive-0.6.2.1-4qCoQ0Hs9z7JzERBp1vJZR
    template-haskell-2.20.0.0 transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-rank2classes/html/rank2classes.haddock

haddock-html:         /usr/share/doc/haskell-rank2classes/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-rank2classes-z-doctests
version:              1.5.5.1
package-name:         rank2classes
lib-name:             doctests
id:                   rank2classes-1.5.5.1-H50dIlCkxEA7xEddKwHhgX-doctests
key:                  rank2classes-1.5.5.1-H50dIlCkxEA7xEddKwHhgX-doctests
license:              BSD-3-Clause
copyright:            (c) 2017 Mario Blažević
maintainer:           Mario Blažević <blamario@protonmail.com>
author:               Mario Blažević
homepage:             https://github.com/blamario/grampa/tree/master/rank2classes
synopsis:
    standard type constructor class hierarchy, only with methods of rank 2 types

description:
    A mirror image of the standard type constructor class hierarchy rooted in '\''Functor'\'', except with methods of rank 2
    types and class instances of kind @(k->*)->*@. The classes enable generic handling of heterogenously typed data
    structures and other neat tricks.

category:             Control, Data, Generics
abi:                  6f78e70309fb6303857b6a05d0c7aa3c
hidden-modules:       MyModule
import-dirs:          /usr/lib/ghc-9.6.6/site-local/rank2classes-1.5.5.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/rank2classes-1.5.5.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/rank2classes-1.5.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-rank2classes
hs-libraries:         HSrank2classes-1.5.5.1-H50dIlCkxEA7xEddKwHhgX-doctests
depends:
    base-4.18.2.1 rank2classes-1.5.5.1-Ajd4u4M9iyH91LaysItqkH

haddock-interfaces:
    /usr/share/doc/haskell-rank2classes/html/rank2classes.haddock

haddock-html:         /usr/share/doc/haskell-rank2classes/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
